// src/AuthenticationProvider.tsx
import React2 from "react";
import { InteractionType } from "@azure/msal-browser";
import { AuthenticatedTemplate, MsalAuthenticationTemplate, MsalProvider, UnauthenticatedTemplate } from "@azure/msal-react";

// src/hooks/useConfiguration.ts
import { useEffect, useState } from "react";
import { BrowserCacheLocation, PublicClientApplication } from "@azure/msal-browser";

// src/configs/index.ts
var environmentConfig = () => ({
  clientId: process.env["VITE_MSAL_CLIENT_ID"],
  authority: process.env["VITE_MSAL_AUTHORITY"],
  loginRedirectUri: process.env["VITE_MSAL_REDIRECT_URL"],
  logoutRedirectUri: process.env["VITE_MSAL_LOGOUT_REDIRECT_URL"],
  scopes: process.env["VITE_MSAL_SCOPES"],
  cacheLoc: process.env["VITE_MSAL_CACHE_LOCATION"],
  tokenInterval: process.env["VITE_MSAL_TOKEN_INTERVAL"],
  tokenThreshold: process.env["VITE_MSAL_TOKEN_REFRESH_THRESHOLD"]
});
var Constants = {
  SPLIT_COMMA: ",",
  TOKEN_INTERVAL: 36e5,
  TOKEN_THRESHOLD: 300,
  SCOPES: ["User.Read"]
};
var ConstantsMessage = {
  MSG_ENV: "Missing environment configuration",
  MSG_CLIENT_ID: "Missing clientId",
  MSG_AUTH_URL: "Missing authority url",
  MSG_REDIRECT_URL: "Missing redirect url"
};

// src/hooks/useConfiguration.ts
var useConfiguration = (authConfig) => {
  const [config, setConfig] = useState();
  const [options, setOptions] = useState();
  useEffect(() => {
    if (authConfig != null && authConfig.option) {
      setOptions(authConfig.option);
    }
    const clientInstance = authConfig && authConfig.instance ? authConfig.instance : defaultInstance();
    const msalInstance = new PublicClientApplication(clientInstance);
    if (msalInstance) {
      setConfig(msalInstance);
    }
  }, [authConfig]);
  const defaultInstance = () => {
    const env = environmentConfig();
    if (!env)
      throw new Error(ConstantsMessage.MSG_ENV);
    let interval = Constants.TOKEN_INTERVAL;
    let threshold = Constants.TOKEN_THRESHOLD;
    let cacheLoc = BrowserCacheLocation.LocalStorage;
    if (!env.clientId) {
      throw new Error(ConstantsMessage.MSG_CLIENT_ID);
    }
    if (!env.authority) {
      throw new Error(ConstantsMessage.MSG_AUTH_URL);
    }
    if (!env.loginRedirectUri) {
      throw new Error(ConstantsMessage.MSG_REDIRECT_URL);
    }
    if (env.tokenInterval) {
      interval = parseInt(env.tokenInterval);
    }
    if (env.tokenThreshold) {
      threshold = parseInt(env.tokenInterval);
    }
    if (env.cacheLoc) {
      cacheLoc = BrowserCacheLocation[env.cacheLoc];
    }
    setOptions({
      scopes: env.scopes?.split(Constants.SPLIT_COMMA),
      tokenInterval: interval,
      tokenThreshold: threshold
    });
    const defaultConfig = {
      auth: {
        clientId: env.clientId,
        authority: env.authority,
        redirectUri: env.loginRedirectUri,
        postLogoutRedirectUri: env.logoutRedirectUri,
        navigateToLoginRequestUrl: false
      },
      cache: {
        cacheLocation: cacheLoc,
        storeAuthStateInCookie: true
      },
      system: {
        tokenRenewalOffsetSeconds: Constants.TOKEN_THRESHOLD
      }
    };
    return defaultConfig;
  };
  return { config, option: options };
};
var useConfiguration_default = useConfiguration;

// src/components/AuthenticationSuccess.tsx
import React, { useEffect as useEffect2, useRef as useRef2 } from "react";
import { useIsAuthenticated as useIsAuthenticated2, useMsal as useMsal2 } from "@azure/msal-react";

// src/hooks/useUserAccount.ts
import { useIsAuthenticated, useMsal } from "@azure/msal-react";
import { InteractionRequiredAuthError } from "@azure/msal-browser";
import { jwtDecode } from "jwt-decode";
import { useUserClaimService, useUserTokenService, useUserService } from "react.framework.userclaim";
import { useRef } from "react";
var useUserAccount = () => {
  let requestScope = Constants.SCOPES;
  const tokenRef = useRef("");
  const isAuthenticated = useIsAuthenticated();
  const { instance, accounts } = useMsal();
  const { setUserToken, getTokenInfo } = useUserTokenService();
  const { setUserClaims } = useUserClaimService();
  const { setUserInfo } = useUserService();
  const getUserToken = async () => {
    let tokenInfo;
    let i = 0;
    do {
      tokenInfo = getTokenInfo();
      if (!tokenInfo || tokenInfo === null) {
        await setTokenToStore();
      }
      if (i == 2)
        break;
      i++;
    } while (!tokenInfo);
    return tokenRef.current;
  };
  const setAcquireTokenToStore = async (scopes) => {
    if (isAuthenticated) {
      if (scopes && scopes.length > 0) {
        requestScope = [...requestScope, ...scopes];
      }
      const tokenInfo = getTokenInfo();
      if (!tokenInfo || tokenInfo === null) {
        setTokenToStore();
      }
    }
  };
  const setTokenToStore = async () => {
    const accountInfo = await getAcquireTokenSilent();
    if (accountInfo) {
      setUserAccountInfoToStore(accountInfo);
    }
  };
  const getAcquireTokenSilent = async () => {
    const authRequest = {
      account: accounts[0],
      scopes: requestScope
    };
    try {
      const response = await instance.acquireTokenSilent(authRequest);
      return response;
    } catch (err) {
      if (err instanceof InteractionRequiredAuthError) {
        await instance.acquireTokenRedirect(authRequest);
      }
    }
  };
  const setUserAccountInfoToStore = (accountInfo) => {
    if (accountInfo) {
      const userTokenExtent = accountInfo;
      const userToken = {
        tokenId: userTokenExtent.tokenId,
        refreshToken: userTokenExtent.accessToken,
        tokenExpirationDate: userTokenExtent.expiresOn,
        userToken: userTokenExtent.accessToken
      };
      setUserToken(userToken);
      if (userToken.userToken) {
        const decodeToken = jwtDecode(userToken.userToken);
        if (decodeToken) {
          const user = {
            id: 1,
            email: decodeToken.upn,
            firstname: decodeToken.family_name,
            lastName: decodeToken.given_name,
            name: decodeToken.name
          };
          setUserInfo(user);
        }
      }
      const userAccountExtent = accountInfo.account;
      if (userAccountExtent) {
        const userClaims = [
          { key: "name", value: userAccountExtent.name ?? "" },
          { key: "username", value: userAccountExtent.username ?? "" }
        ];
        setUserClaims(userClaims);
      }
      tokenRef.current = userTokenExtent.accessToken;
    }
  };
  const setUserActiveAccount = async () => {
    const currentAccounts = instance.getAllAccounts();
    if (currentAccounts.length > 0) {
      instance.setActiveAccount(currentAccounts[0]);
    }
  };
  return { getUserToken, setAcquireTokenToStore, setUserActiveAccount };
};
var useUserAccount_default = useUserAccount;

// src/components/AuthenticationSuccess.tsx
var AuthenticationSuccess = ({ children, option }) => {
  const interval = useRef2(null);
  const isAuthenticated = useIsAuthenticated2();
  const { setAcquireTokenToStore, setUserActiveAccount } = useUserAccount_default();
  const { accounts } = useMsal2();
  useEffect2(() => {
    if (isAuthenticated) {
      setUserActiveAccount();
      setAcquireTokenToStore(option?.scopes);
      if (option != null) {
        interval.current = setInterval(checkTokenExpiry, option.tokenInterval);
      }
    }
    return () => clearInterval(interval.current);
  }, [isAuthenticated]);
  const checkTokenExpiry = () => {
    if (isAuthenticated) {
      const account = accounts[0];
      const idTokenClaimsExp = account.idTokenClaims?.exp;
      if (idTokenClaimsExp) {
        const currentTime = Math.floor(Date.now() / 1e3);
        const timeUntilExpiry = idTokenClaimsExp - currentTime;
        const tokenThreshold = option?.tokenThreshold ?? 0;
        if (timeUntilExpiry <= tokenThreshold) {
          setAcquireTokenToStore(option?.scopes);
        }
      }
    }
  };
  return /* @__PURE__ */ React.createElement(React.Fragment, null, children);
};
var AuthenticationSuccess_default = AuthenticationSuccess;

// src/AuthenticationProvider.tsx
var AuthenticationProvider = ({ children, beforeAuthComponent, authConfig }) => {
  const { config, option } = useConfiguration_default(authConfig);
  return config != null ? /* @__PURE__ */ React2.createElement(MsalProvider, { instance: config }, beforeAuthComponent ? /* @__PURE__ */ React2.createElement(React2.Fragment, null, /* @__PURE__ */ React2.createElement(UnauthenticatedTemplate, null, beforeAuthComponent), /* @__PURE__ */ React2.createElement(AuthenticatedTemplate, null, /* @__PURE__ */ React2.createElement(AuthenticationSuccess_default, { option }, children))) : /* @__PURE__ */ React2.createElement(React2.Fragment, null, /* @__PURE__ */ React2.createElement(MsalAuthenticationTemplate, { authenticationRequest: { scopes: option?.scopes }, interactionType: InteractionType.Redirect }, /* @__PURE__ */ React2.createElement(AuthenticationSuccess_default, { option }, children)))) : null;
};
var AuthenticationProvider_default = AuthenticationProvider;

// src/hooks/useMsalAuthentication.ts
import { useMsal as useMsal3 } from "@azure/msal-react";
var useMsalAuthentication = () => {
  const { instance } = useMsal3();
  const loginRedirect = () => {
    instance.loginRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const loginPopup = () => {
    instance.loginPopup().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutRedirect = () => {
    instance.logoutRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutPopup = () => {
    instance.logoutPopup({
      account: instance.getActiveAccount()
    }).catch((error) => {
      throw new Error(error);
    });
  };
  return { loginRedirect, loginPopup, logoutRedirect, logoutPopup };
};
var useMsalAuthentication_default = useMsalAuthentication;

// src/hooks/useAuthenticated.ts
import { useIsAuthenticated as useIsAuthenticated3 } from "@azure/msal-react";
var useAuthenticated = () => {
  const isAuthenticated = useIsAuthenticated3();
  return isAuthenticated;
};
var useAuthenticated_default = useAuthenticated;
export {
  AuthenticationProvider_default as AuthenticationProvider,
  useUserAccount_default as useAccount,
  useAuthenticated_default as useAuthenticated,
  useMsalAuthentication_default as useAuthentication
};
